/*
 * Copyright (c) 2004-2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: MyLeadConfiguration.java,v 1.4 2007/02/23 01:08:07 sshirasu Exp $
 */

package edu.indiana.extreme.xbaya.mylead;

import java.net.URI;

import edu.indiana.extreme.xbaya.event.Event;
import edu.indiana.extreme.xbaya.event.EventProducer;
import edu.indiana.extreme.xbaya.event.Event.Type;

/**
 * @author Satoshi Shirasuna
 */
public class MyLeadConfiguration extends EventProducer {

    private static final Event event = new Event(
            Type.MYLEAD_CONFIGURATION_CHANGED);

    private URI url;

    private String user;

    private String project;

    /**
     * Constructs a MyLeadConfiguration.
     * 
     */
    public MyLeadConfiguration() {
        // Nothing
    }

    /**
     * Constructs a MyLeadConfiguration.
     * 
     * @param url
     * @param user
     * @param project
     */
    public MyLeadConfiguration(URI url, String user, String project) {
        this.url = url;
        this.user = user;
        this.project = project;
    }

    /**
     * @param configuration
     */
    public void set(MyLeadConfiguration configuration) {
        set(configuration.getURL(), configuration.getUser(), configuration
                .getProject());
    }

    /**
     * @param url
     * @param user
     * @param project
     */
    public void set(URI url, String user, String project) {
        this.url = url;
        this.user = user;
        this.project = project;
        sendSafeEvent(event);
    }

    /**
     * @return Returns the url.
     */
    public URI getURL() {
        return this.url;
    }

    /**
     * @return Returns the userId.
     */
    public String getUser() {
        return this.user;
    }

    /**
     * @return Returns the investigationId.
     */
    public String getProject() {
        return this.project;
    }

    /**
     * Checks if the configuration is complete to use.
     * 
     * @return true if the configuration is complete; false otherwise.
     */
    public boolean isValid() {
        if (this.url == null) {
            return false;
        }
        if (this.user == null || this.user.equals("")) {
            return false;
        }
        if (this.project == null || this.project.equals("")) {
            return false;
        }
        return true;
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2004-2007 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
